"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ApplicationVersionEnum = exports.ApplicationNameEnum = exports.DslSourceEnum = exports.ExecutionStrategyEnum = exports.BuildNotificationHelper = void 0;
const task = require("azure-pipelines-task-lib/task");
const Constants_1 = require("./Constants");
const BuildNotificationModel_1 = require("./model/BuildNotificationModel");
const CommitSource_1 = require("./model/CommitSource");
const NameValuePair_1 = require("./model/NameValuePair");
const ReleaseDsl_1 = require("./model/ReleaseDsl");
const cddUtils = require("./CDDUtils");
const Commits_1 = require("./model/Commits");
class BuildNotificationHelper {
    static getBuildNotificationModel() {
        return __awaiter(this, void 0, void 0, function* () {
            let applicationName = BuildNotificationHelper.getApplicationName();
            let applicationVersion = BuildNotificationHelper.getApplicationVersion();
            let releaseTokens = BuildNotificationHelper.getReleaseTokens();
            let commitSource = BuildNotificationHelper.getCommitSource();
            let testSource = BuildNotificationHelper.getTestSource();
            let releaseDsl = BuildNotificationHelper.getReleaseDsl(applicationName, applicationVersion);
            let commits = yield BuildNotificationHelper.getCommits();
            let buildNotificationModel = new BuildNotificationModel_1.BuildNotificationModel();
            buildNotificationModel.setApplicationVersionBuildNumber(BuildNotificationHelper.getBuildNumber());
            buildNotificationModel.setApplicationVersionBuildUrl(BuildNotificationHelper.getBuildUrl());
            buildNotificationModel.setApplicationName(applicationName);
            buildNotificationModel.setApplicationVersion(applicationVersion);
            buildNotificationModel.setReleaseTokens(releaseTokens);
            buildNotificationModel.setCommitSource(commitSource);
            buildNotificationModel.setTestSources(testSource);
            buildNotificationModel.setReleaseDsl(releaseDsl);
            buildNotificationModel.setCommits(commits);
            return buildNotificationModel;
        });
    }
    static getCommits() {
        return __awaiter(this, void 0, void 0, function* () {
            const cddEndpoint = task.getInput('cddEndpoint', true);
            let azureToken = task.getEndpointAuthorizationParameter(cddEndpoint, 'azureToken', false);
            let [prevCommitId, prevCommitIdErr] = yield cddUtils.handle(cddUtils.getPreviousSuccessfullRunCommit(azureToken));
            if (prevCommitIdErr)
                throw new Error('Could not fetch commit details,please check Azure Devops Token .Reason:' + prevCommitIdErr);
            let currentCommit = process.env.BUILD_SOURCEVERSION;
            let commitArr = [];
            if (!BuildNotificationHelper.isEmptyOrNull(prevCommitId) && prevCommitId != currentCommit) {
                commitArr.push(new Commits_1.Commits(prevCommitId));
            }
            commitArr.push(new Commits_1.Commits(currentCommit));
            return commitArr;
        });
    }
    static getReleaseDsl(applicationName, applicationVersion) {
        let releaseDsl;
        let notificationExecutionStrategy = BuildNotificationHelper.getNotificationExecutionStrategy();
        let dslParameter = BuildNotificationHelper.getDslParameters();
        switch (notificationExecutionStrategy) {
            case Constants_1.Constants.CREATE_RELEASE: {
                let dslSource = BuildNotificationHelper.getDslSource();
                if (dslSource === DslSourceEnum.FILE_SOURCE) {
                    let fileSourceName = BuildNotificationHelper.getFileSourceName();
                    let dslFilename = BuildNotificationHelper.getFileName();
                    let fileSourceParameters = BuildNotificationHelper.getFileSourceParameters();
                    releaseDsl = new ReleaseDsl_1.FileSourceReleaseDsl(dslFilename, fileSourceName, fileSourceParameters, dslParameter);
                }
                else {
                    releaseDsl = new ReleaseDsl_1.BusinessApplicationReleaseDsl(dslParameter);
                }
                break;
            }
            case Constants_1.Constants.RUN_TESTS: {
                let onlyRunTestsSubset = BuildNotificationHelper.isOnlyRunTestsSubset();
                releaseDsl = new ReleaseDsl_1.RunTestsReleaseDsl(applicationName, applicationVersion, onlyRunTestsSubset);
                break;
            }
            default: {
            }
        }
        return releaseDsl;
    }
    static getBuildUrl() {
        let tfsSystemUrl = process.env.SYSTEM_TEAMFOUNDATIONSERVERURI;
        let project = process.env.SYSTEM_TEAMPROJECT;
        let buildId = process.env.BUILD_BUILDID;
        const buildUrl = `${tfsSystemUrl}${project}/_build/results?buildId=${buildId}&view=results`;
        return buildUrl;
    }
    static getBuildNumber() {
        return process.env["BUILD_BUILDNUMBER"];
    }
    static getApplicationName() {
        let applicationNameSelection = task.getInput('application', true);
        let customAppName = task.getInput('applicationName', false);
        applicationNameSelection = applicationNameSelection || Constants_1.Constants.REPO_AS_APPLICATION_NAME;
        let applicationName;
        if (applicationNameSelection == Constants_1.Constants.REPO_AS_APPLICATION_NAME) {
            // code to get repo name from env
            let repoUrl = process.env.BUILD_REPOSITORY_URI || '';
            let start = repoUrl.lastIndexOf("/");
            let end = repoUrl.lastIndexOf(".");
            if (end < start) {
                end = repoUrl.length;
            }
            ;
            if (start != -1) {
                applicationName = repoUrl.substring(start + 1, end);
                console.log("[INFO] Application name will be derived from repository name");
            }
            else {
                throw `Cannot extract application name ,reason :invalid repository url ${repoUrl}`;
            }
        }
        else {
            if (!(Object.values(ApplicationNameEnum).includes(applicationNameSelection))) {
                throw "Invalid Application Name selection :" + applicationNameSelection;
            }
            if (BuildNotificationHelper.isEmptyOrNull(customAppName)) {
                throw 'Application Name is required';
            }
            applicationName = customAppName;
        }
        return applicationName;
    }
    static getApplicationVersion() {
        let applicationVersionSelection = task.getInput('applicationVersion', true);
        let customApplicationVersion = task.getInput('applicationVersionName', false);
        let applicationVersionName;
        applicationVersionSelection = applicationVersionSelection || Constants_1.Constants.BRANCH_AS_APPLICATION_VERSION;
        if (applicationVersionSelection == Constants_1.Constants.BRANCH_AS_APPLICATION_VERSION) {
            applicationVersionName = process.env.BUILD_SOURCEBRANCHNAME;
            console.log("[INFO] Application Version will be derived from repository branch");
        }
        else {
            if (!(Object.values(ApplicationVersionEnum).includes(applicationVersionSelection))) {
                throw "Invalid Application Version selection :" + applicationVersionSelection;
            }
            if (BuildNotificationHelper.isEmptyOrNull(customApplicationVersion)) {
                throw 'Application Version is required';
            }
            applicationVersionName = customApplicationVersion;
        }
        return applicationVersionName;
    }
    static getDslParameters() {
        let userJsonString = task.getInput('dslParameter');
        try {
            let dslParameter = userJsonString ? JSON.parse(userJsonString) : userJsonString;
            return dslParameter;
        }
        catch (err) {
            console.log(err);
            throw "Invalid dsl parameter json :" + userJsonString;
        }
    }
    static getFileSourceParameters() {
        let userJsonString = task.getInput('fileSourceParameters');
        let fileSourceParameters;
        if (!BuildNotificationHelper.isEmptyOrNull(userJsonString)) {
            try {
                fileSourceParameters = userJsonString ? JSON.parse(userJsonString) : userJsonString;
            }
            catch (err) {
                console.log(err);
                throw "Invalid Filesource parameter json :" + userJsonString;
            }
        }
        return fileSourceParameters;
    }
    static getFileName() {
        let dslFilename = task.getInput('dslFilename');
        return dslFilename;
    }
    static getFileSourceName() {
        let fileSourceName = task.getInput('fileSourceName');
        return fileSourceName;
    }
    static isOnlyRunTestsSubset() {
        let onlyRunTestsSubset = task.getBoolInput('runSubset');
        if (onlyRunTestsSubset == null) {
            onlyRunTestsSubset = true;
        }
        return onlyRunTestsSubset;
    }
    static getReleaseTokens() {
        let userJsonString = task.getInput('cddTokens');
        let releaseTokens;
        if (!BuildNotificationHelper.isEmptyOrNull(userJsonString)) {
            try {
                releaseTokens = BuildNotificationHelper.toNameValuePairArray(userJsonString);
            }
            catch (err) {
                console.log(err);
                throw 'Release Token json is invalid :' + userJsonString;
            }
        }
        return releaseTokens;
    }
    static getCommitSource() {
        let userJsonString = task.getInput('commitSource');
        let commitSource;
        if (!BuildNotificationHelper.isEmptyOrNull(userJsonString)) {
            try {
                commitSource = new CommitSource_1.CommitSource(userJsonString);
            }
            catch (err) {
                console.log(err);
                throw 'Source Control json is invalid :' + userJsonString;
            }
        }
        return commitSource;
    }
    static getTestSource() {
        let userJsonString = task.getInput('testData');
        let testData;
        if (!BuildNotificationHelper.isEmptyOrNull(userJsonString)) {
            try {
                testData = JSON.parse(userJsonString);
            }
            catch (err) {
                console.log(err);
                throw 'Test Source json is invalid :' + userJsonString;
            }
        }
        return testData;
    }
    static getNotificationExecutionStrategy() {
        let notificationExecutionStrategy = task.getInput('notificationExecutionStrategy');
        if (!(Object.values(ExecutionStrategyEnum).includes(notificationExecutionStrategy))) {
            throw "Invalid Notification execution strategy :" + notificationExecutionStrategy;
        }
        return notificationExecutionStrategy;
    }
    static getDslSource() {
        let dslSource = task.getInput('dslSource');
        if (!(Object.values(DslSourceEnum).includes(dslSource))) {
            throw "Invalid DSL Source :" + dslSource;
        }
        return dslSource;
    }
    static toNameValuePairArray(inputJson) {
        let array = [];
        let obj = JSON.parse(inputJson);
        Object.keys(obj).forEach(key => {
            array.push(new NameValuePair_1.NameValuePair(key, obj[key]));
        });
        return array;
    }
    static toParametersJson(jsonString) {
        let tmpJson = {};
        return tmpJson["parameters"] = JSON.parse(jsonString);
    }
    static isEmptyOrNull(input) {
        if (typeof input === 'undefined' || input == null || input === '') {
            return true;
        }
        return false;
    }
}
exports.BuildNotificationHelper = BuildNotificationHelper;
var ExecutionStrategyEnum;
(function (ExecutionStrategyEnum) {
    ExecutionStrategyEnum["EXECUTE_RELEASE"] = "executeExistingRelease";
    ExecutionStrategyEnum["CREATE_RELEASE"] = "createRelease";
    ExecutionStrategyEnum["RUN_TESTS"] = "onlyRunTests";
})(ExecutionStrategyEnum = exports.ExecutionStrategyEnum || (exports.ExecutionStrategyEnum = {}));
var DslSourceEnum;
(function (DslSourceEnum) {
    DslSourceEnum["FILE_SOURCE"] = "fileSource";
    DslSourceEnum["BUSINESS_APPLICATION"] = "businessApplication";
})(DslSourceEnum = exports.DslSourceEnum || (exports.DslSourceEnum = {}));
var ApplicationNameEnum;
(function (ApplicationNameEnum) {
    ApplicationNameEnum["REPO_NAME_AS_APPLICATION_NAME"] = "repoNameAsApplicationName";
    ApplicationNameEnum["CUSTOM_APPLICATION_NAME"] = "customApplicationName";
})(ApplicationNameEnum = exports.ApplicationNameEnum || (exports.ApplicationNameEnum = {}));
var ApplicationVersionEnum;
(function (ApplicationVersionEnum) {
    ApplicationVersionEnum["BRANCH_NAME_AS_APPLICATION_VERSION"] = "branchNameAsVersion";
    ApplicationVersionEnum["CUSTOM_APPLICATION_VERSION"] = "customApplicationVersion";
})(ApplicationVersionEnum = exports.ApplicationVersionEnum || (exports.ApplicationVersionEnum = {}));
