"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CDDConfiguration = void 0;
const Constants_1 = require("./Constants");
const URL = require('url').URL;
class CDDConfiguration {
    constructor(cddServerUrl, tenantId, apiKey) {
        this.protocol = "https";
        this.useSSL = true;
        this.baseUrl = '';
        if (!cddServerUrl) {
            throw "CDD server url missing.";
        }
        if (!apiKey) {
            throw "API key missing.";
        }
        try {
            let urlObject = new URL(cddServerUrl);
            this.cdeServerName = urlObject.hostname;
            this.cdeServerPort = urlObject.port;
            this.protocol = urlObject.protocol;
            if ((!this.cdeServerPort || this.cdeServerPort == "") && this.protocol == Constants_1.Constants.HTTPS_PROTOCOL) {
                this.baseUrl = `${this.protocol}//${this.cdeServerName}`;
                this.cdeServerPort = "443";
            }
            else {
                this.baseUrl = `${this.protocol}//${this.cdeServerName}:${this.cdeServerPort}`;
            }
        }
        catch (error) {
            console.log(error);
            throw `Invalid cdd server url ${cddServerUrl}`;
        }
        this.tenantId = tenantId;
        this.apiKey = apiKey;
    }
    getBuildNotificationPath() {
        const buildNotificationApi = "v1/applications/application-versions/application-version-builds";
        const buildNotificationPath = `/cdd/design/${this.tenantId}/${buildNotificationApi}`;
        return buildNotificationPath;
    }
    getBaseUrl() { return this.baseUrl; }
    getApiKey() { return this.apiKey; }
    getCdeServerName() { return this.cdeServerName; }
    getCdeServerPort() { return this.cdeServerPort; }
    getProtocol() { return this.protocol; }
}
exports.CDDConfiguration = CDDConfiguration;
