"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.validateAzureServerSettings = exports.getEnv = exports.getPreviousSuccessfullRunCommit = exports.sendNotificationToCDD = exports.handle = void 0;
const Constants_1 = require("./Constants");
const vm = require("azure-devops-node-api");
const bi = require("azure-devops-node-api/interfaces/BuildInterfaces");
const https = require('https');
const http = require('http');
exports.handle = (promise) => {
    return promise
        .then(data => ([data, undefined]))
        .catch(error => Promise.resolve([undefined, error]));
};
function sendNotificationToCDD(cddConfig, notificationModel, ignoreNonExistentCDDApp) {
    return __awaiter(this, void 0, void 0, function* () {
        var reqJson = JSON.stringify(notificationModel, null, 1);
        if (ignoreNonExistentCDDApp == null) {
            console.log("Setting ignore non existent cdd app to true");
            ignoreNonExistentCDDApp = true;
        }
        const buildNotificationPath = cddConfig.getBuildNotificationPath();
        console.log("[INFO] IgnoreNonExistent CDD Application:" + ignoreNonExistentCDDApp);
        console.log("[INFO] Request Json:" + reqJson);
        console.log("[INFO] Base url :" + cddConfig.getBaseUrl());
        console.log("[INFO] API path:" + buildNotificationPath);
        const apiKey = cddConfig.getApiKey();
        const options = {
            hostname: cddConfig.getCdeServerName(),
            port: cddConfig.getCdeServerPort(),
            path: buildNotificationPath,
            method: 'POST',
            headers: {
                'Accept': 'application/json',
                'Content-Type': 'application/json',
                'Authorization': 'Bearer ' + apiKey
            },
        };
        //console.log("Calling url: "+options.hostname);
        let client;
        if (cddConfig.getProtocol() == Constants_1.Constants.HTTPS_PROTOCOL) {
            client = https;
        }
        else {
            client = http;
        }
        return new Promise(function (resolve, reject) {
            var req = client.request(options, function (res) {
                // cumulate data
                var body = '';
                res.on('data', function (chunk) {
                    body += chunk;
                });
                // resolve on end
                res.on('end', function () {
                    let respJson = JSON.parse(body);
                    try {
                        handleResponse(res.statusCode, respJson, ignoreNonExistentCDDApp);
                        resolve(respJson);
                    }
                    catch (err) {
                        reject(err);
                    }
                });
            });
            // reject on request error
            req.on('error', function (err) {
                // This is not a "Second reject", just a different sort of failure
                console.log("[ERROR] Request failed");
                reject(err);
            });
            req.write(reqJson);
            // IMPORTANT
            req.end();
        });
    });
}
exports.sendNotificationToCDD = sendNotificationToCDD;
function getPreviousSuccessfullRunCommit(azureToken) {
    return __awaiter(this, void 0, void 0, function* () {
        return new Promise(function (resolve, reject) {
            return __awaiter(this, void 0, void 0, function* () {
                let tfsSystemUrl = getEnv('SYSTEM_TEAMFOUNDATIONSERVERURI');
                let project = getEnv('SYSTEM_TEAMPROJECT');
                let vsts;
                let vstsErr;
                [vsts, vstsErr] = yield exports.handle(getWebApi(tfsSystemUrl, azureToken));
                if (vstsErr) {
                    reject(vstsErr);
                }
                else {
                    let vstsBuild = yield vsts.getBuildApi();
                    let builds = yield vstsBuild.getBuilds(project, null, // definitions: number[] 
                    null, // queues: number[]
                    null, // buildNumber
                    null, //new Date(2016, 1, 1),       // minFinishTime
                    null, // maxFinishTime
                    null, // requestedFor: string
                    bi.BuildReason.All, // reason
                    bi.BuildStatus.Completed, bi.BuildResult.Succeeded, null, // tagFilters: string[]
                    null, // properties: string[]
                    //bi.DefinitionType.Build,
                    1 // top: number
                    );
                    let totalBuild = builds.length;
                    //console.log(`${totalBuild} builds returned`);
                    let lastSuccessfulCommitId = "";
                    if (totalBuild == 1) {
                        builds.forEach((build) => {
                            console.log("[INFO] ", build.buildNumber, bi.BuildResult[build.result], "on", build.finishTime.toDateString(), build.sourceVersion);
                            lastSuccessfulCommitId = build.sourceVersion;
                        });
                    }
                    resolve(lastSuccessfulCommitId);
                }
            });
        });
    });
}
exports.getPreviousSuccessfullRunCommit = getPreviousSuccessfullRunCommit;
function getWebApi(serverUrl, token) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            return new Promise((resolve, reject) => __awaiter(this, void 0, void 0, function* () {
                let authHandler = vm.getPersonalAccessTokenHandler(token);
                let option = {
                    allowRetries: false
                };
                let vsts = new vm.WebApi(serverUrl, authHandler, option);
                let connData;
                let connDataErr;
                [connData, connDataErr] = yield exports.handle(vsts.connect());
                if (connDataErr) {
                    reject(connDataErr);
                }
                else {
                    console.log(`Fetching commit details of last successfull run for : ${connData.authenticatedUser.providerDisplayName}`);
                    resolve(vsts);
                }
            }));
        }
        catch (err) {
            console.log(err);
            throw err;
        }
    });
}
function getEnv(name) {
    let val = process.env[name];
    if (!val) {
        console.error(`${name} env var not set`);
        throw `${name} env var not set`;
    }
    return val;
}
exports.getEnv = getEnv;
function handleResponse(statusCode, respJson, ignoreNonExistentCDDApp) {
    console.log("[INFO] Status code = " + statusCode);
    console.log("[INFO] Response from CDD :" + JSON.stringify(respJson));
    if (statusCode === 200) {
        return;
    }
    else if (statusCode === 404) {
        let messageCode = respJson.errors[0].messageCode;
        if ("entityNotFound" === messageCode && ignoreNonExistentCDDApp) {
            console.log("[INFO] Ignore non existing application and version");
            console.log("[INFO] Entity not found error!!!, post-build action will continue");
            return;
        }
        throw Constants_1.Constants.APP_NAME_AND_VERSION_ERROR_MSG;
    }
    else {
        if (statusCode === 401) {
            throw Constants_1.Constants.API_KEY_AND_TENANT_ID_ERROR_MSG;
        }
        throw Constants_1.Constants.GENERAL_ERROR_MSG;
    }
}
function validateAzureServerSettings() {
    return __awaiter(this, void 0, void 0, function* () {
        let azureServerUrl;
        try {
            azureServerUrl = getEnv('SYSTEM_TEAMFOUNDATIONSERVERURI');
            getEnv('SYSTEM_TEAMPROJECT');
        }
        catch (err) {
            throw "Required environment Variables : SYSTEM_TEAMFOUNDATIONSERVERURI and/or SYSTEM_TEAMPROJECT are not found";
        }
        let isServerReachable = yield isAzureServerReachable(azureServerUrl);
        if (!isServerReachable) {
            throw `${azureServerUrl} not reachable`;
        }
    });
}
exports.validateAzureServerSettings = validateAzureServerSettings;
function isAzureServerReachable(azureServerUrl) {
    return __awaiter(this, void 0, void 0, function* () {
        let isAzureReachable = true;
        try {
            let urlObject = new URL(azureServerUrl);
            let port = urlObject.port;
            let protocol = urlObject.protocol;
            if (port === '') {
                if (protocol === Constants_1.Constants.HTTP_PROTOCOL) {
                    port = "80";
                }
                else {
                    port = "443";
                }
            }
            const options = {
                hostname: urlObject.hostname,
                port: port,
                path: urlObject.pathname,
                method: 'GET'
            };
            let client;
            if (protocol == Constants_1.Constants.HTTPS_PROTOCOL) {
                client = https;
            }
            else {
                client = http;
            }
            let statusCode = yield getAzureServerStatus(client, options);
            if (statusCode === -1) {
                isAzureReachable = false;
            }
        }
        catch (err) {
            isAzureReachable = false;
        }
        return isAzureReachable;
    });
}
function getAzureServerStatus(client, options) {
    return __awaiter(this, void 0, void 0, function* () {
        return new Promise(function (resolve, reject) {
            const req = client.request(options, res => {
                //console.log(`statusCode: ${res.statusCode}`);		  
                res.on('data', d => {
                    resolve(res.statusCode);
                });
            });
            req.on('error', error => {
                reject(-1);
            });
            req.end();
        });
    });
}
