"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const task = require("azure-pipelines-task-lib/task");
const BuildNotificationHelper_1 = require("./BuildNotificationHelper");
const CDDConfiguration_1 = require("./CDDConfiguration");
const cddUtils = require("./CDDUtils");
function run() {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            const cddEndpoint = task.getInput('cddEndpoint', true);
            if (cddEndpoint == "") {
                throw "Endpoint not configured. Please create a CDD server endpoint.";
            }
            yield cddUtils.validateAzureServerSettings();
            const endpointUrl = task.getEndpointUrl(cddEndpoint, true);
            var cddConfig = new CDDConfiguration_1.CDDConfiguration(endpointUrl, task.getEndpointDataParameter(cddEndpoint, 'cddTenantId', false), task.getEndpointAuthorizationParameter(cddEndpoint, 'apitoken', true));
            let buildNotificationModel = yield BuildNotificationHelper_1.BuildNotificationHelper.getBuildNotificationModel();
            let ignoreNonExistentCDDApp = task.getBoolInput('ignoreNonExistentCDDApp');
            cddUtils.sendNotificationToCDD(cddConfig, buildNotificationModel, ignoreNonExistentCDDApp).then(function (response) { _ifSuccess(response); }, function (error) { _ifFailed(error); });
        }
        catch (err) {
            console.log("[ERROR]Notification task failed due to :" + err);
            task.setResult(task.TaskResult.Failed, err);
        }
        finally {
        }
    });
}
function _ifSuccess(responseJson) {
    console.log("[Success] Task completed successfully");
    task.setVariable("BUILD_RESULT", responseJson, false, true);
    console.log("------------Task ended-----------");
}
function _ifFailed(error) {
    console.log("[Error Message] " + error);
    console.log("-----------Task Failed----------");
    task.setResult(task.TaskResult.Failed, error);
}
run();
