"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const assert = require("assert");
const mock_test_1 = require("azure-pipelines-task-lib/mock-test");
const STATUS_CODE_200 = '[INFO] Status code = 200';
const STATUS_CODE_400 = '[INFO] Status code = 400';
const STATUS_CODE_404 = '[INFO] Status code = 404';
const TASK_SUCCESS_MSG = '[Success] Task completed successfully';
describe('Send Notification task tests', function () {
    this.timeout(parseInt(process.env.TASK_TEST_TIMEOUT) || 20000);
    before(function () {
    });
    after(() => {
    });
    it('01- Endpoint not set', function (done) {
        let tp = path.join(__dirname, 'endpointNotFoundFailure.js');
        let mtr = new mock_test_1.MockTestRunner(tp);
        let errMsg = 'Error: Input required: cddEndpoint';
        mtr.run();
        console.log("Task Output: ", mtr.stdout);
        assert.strictEqual(mtr.succeeded, false, 'should have failed');
        assert.strictEqual(mtr.warningIssues.length, 0, "should have no warnings");
        assert.strictEqual(mtr.errorIssues.length, 1, "should have 1 error issue");
        assert.strictEqual(mtr.errorIssues[0], errMsg, 'error issue output');
        assert.strictEqual(mtr.stdout.indexOf('Task completed successfully'), -1, "Should not display: Task completed successfully");
        done();
    });
    it('02 -Env Var SYSTEM_TEAMFOUNDATIONSERVERURI not set', function (done) {
        let tp = path.join(__dirname, 'envVarSystemTeamFoundationServerUriFailure.js');
        let mtr = new mock_test_1.MockTestRunner(tp);
        let errMsg = 'Required environment Variables : SYSTEM_TEAMFOUNDATIONSERVERURI and/or SYSTEM_TEAMPROJECT are not found';
        mtr.run();
        console.log("Task Output: ", mtr.stdout);
        assert.strictEqual(mtr.succeeded, false, 'should have failed');
        assert.strictEqual(mtr.warningIssues.length, 0, "should have no warnings");
        assert.strictEqual(mtr.errorIssues.length, 1, "should have 1 error issue");
        assert.strictEqual(mtr.errorIssues[0], errMsg, 'error issue output');
        assert.strictEqual(mtr.stdout.indexOf('Task completed successfully'), -1, "Should not display: Task completed successfully");
        done();
    });
    it('03 -Env Var SYSTEM_TEAMPROJECT not set', function (done) {
        let tp = path.join(__dirname, 'envVarSystemTeamProjectFailure.js');
        let mtr = new mock_test_1.MockTestRunner(tp);
        let errMsg = 'Required environment Variables : SYSTEM_TEAMFOUNDATIONSERVERURI and/or SYSTEM_TEAMPROJECT are not found';
        mtr.run();
        console.log("Task Output: ", mtr.stdout);
        assert.strictEqual(mtr.succeeded, false, 'should have failed');
        assert.strictEqual(mtr.warningIssues.length, 0, "should have no warnings");
        assert.strictEqual(mtr.errorIssues.length, 1, "should have 1 error issue");
        assert.strictEqual(mtr.errorIssues[0], errMsg, 'error issue output');
        assert.strictEqual(mtr.stdout.indexOf('Task completed successfully'), -1, "Should not display: Task completed successfully");
        done();
    });
    it('04- Invalid release tokens', function (done) {
        let tp = path.join(__dirname, 'invalidReleaseTokens.js');
        let mtr = new mock_test_1.MockTestRunner(tp);
        let errMsg = 'Release Token json is invalid :{"TOKEN1":Value1","TOKEN2":"Value2"}';
        mtr.run();
        console.log("Task Output: ", mtr.stdout);
        assert.strictEqual(mtr.succeeded, false, 'should have failed');
        assert.strictEqual(mtr.warningIssues.length, 0, "should have no warnings");
        assert.strictEqual(mtr.errorIssues.length, 1, "should have 1 error issue");
        assert.strictEqual(mtr.errorIssues[0], errMsg, 'error issue output');
        assert.strictEqual(mtr.stdout.indexOf('Task completed successfully'), -1, "Should not display: Task completed successfully");
        done();
    });
    it('05- Invalid commit source', function (done) {
        let tp = path.join(__dirname, 'invalidCommitSource.js');
        let mtr = new mock_test_1.MockTestRunner(tp);
        let errMsg = 'Source Control json is invalid :{"itemsToReturn":1,2,7,8"}';
        mtr.run();
        console.log("Task Output: ", mtr.stdout);
        assert.strictEqual(mtr.succeeded, false, 'should have failed');
        assert.strictEqual(mtr.warningIssues.length, 0, "should have no warnings");
        assert.strictEqual(mtr.errorIssues.length, 1, "should have 1 error issue");
        assert.strictEqual(mtr.errorIssues[0], errMsg, 'error issue output');
        assert.strictEqual(mtr.stdout.indexOf('Task completed successfully'), -1, "Should not display: Task completed successfully");
        done();
    });
    it('06- Invalid test source', function (done) {
        let tp = path.join(__dirname, 'invalidTestSource.js');
        let mtr = new mock_test_1.MockTestRunner(tp);
        let errMsg = 'Test Source json is invalid :[ {"name": "DemoTSTemplate" "parameters": {"branch":"master"} }]';
        mtr.run();
        console.log("Task Output: ", mtr.stdout);
        assert.strictEqual(mtr.succeeded, false, 'should have failed');
        assert.strictEqual(mtr.warningIssues.length, 0, "should have no warnings");
        assert.strictEqual(mtr.errorIssues.length, 1, "should have 1 error issue");
        assert.strictEqual(mtr.errorIssues[0], errMsg, 'error issue output');
        assert.strictEqual(mtr.stdout.indexOf('Task completed successfully'), -1, "Should not display: Task completed successfully");
        done();
    });
    it('07- Invalid dsl source', function (done) {
        let tp = path.join(__dirname, 'invalidDslSource.js');
        let mtr = new mock_test_1.MockTestRunner(tp);
        let errMsg = 'Invalid DSL Source :invalidDslSource';
        mtr.run();
        console.log("Task Output: ", mtr.stdout);
        assert.strictEqual(mtr.succeeded, false, 'should have failed');
        assert.strictEqual(mtr.warningIssues.length, 0, "should have no warnings");
        assert.strictEqual(mtr.errorIssues.length, 1, "should have 1 error issue");
        assert.strictEqual(mtr.errorIssues[0], errMsg, 'error issue output');
        assert.strictEqual(mtr.stdout.indexOf('Task completed successfully'), -1, "Should not display: Task completed successfully");
        done();
    });
    it('08- Invalid execution strategy', function (done) {
        let tp = path.join(__dirname, 'invalidExecutionStrategy.js');
        let mtr = new mock_test_1.MockTestRunner(tp);
        let errMsg = 'Invalid Notification execution strategy :invalidExecutionStrategy';
        mtr.run();
        console.log("Task Output: ", mtr.stdout);
        assert.strictEqual(mtr.succeeded, false, 'should have failed');
        assert.strictEqual(mtr.warningIssues.length, 0, "should have no warnings");
        assert.strictEqual(mtr.errorIssues.length, 1, "should have 1 error issue");
        assert.strictEqual(mtr.errorIssues[0], errMsg, 'error issue output');
        assert.strictEqual(mtr.stdout.indexOf('Task completed successfully'), -1, "Should not display: Task completed successfully");
        done();
    });
    it('09- Execute Release minimum inputs', function (done) {
        let tp = path.join(__dirname, 'executeReleaseMinInputs.js');
        let mtr = new mock_test_1.MockTestRunner(tp);
        mtr.run();
        console.log("Task Output: ", mtr.stdout);
        assert.strictEqual(mtr.succeeded, true, 'should have succeeded');
        assert.strictEqual(mtr.warningIssues.length, 0, "should have no warnings");
        assert.strictEqual(mtr.errorIssues.length, 0, "should have no errors");
        assert.strictEqual(mtr.stdout.indexOf('[INFO] IgnoreNonExistent CDD Application:false') >= 0, true, "Ignore non existent application must be false");
        assert.strictEqual(mtr.stdout.indexOf(STATUS_CODE_200) >= 0, true, "Status code from cdd must be 200");
        assert.strictEqual(mtr.stdout.indexOf(TASK_SUCCESS_MSG) >= 0, true, "Task must complete successfully");
        done();
    });
    it('10- Ignore Non-existent application - unchecked', function (done) {
        let tp = path.join(__dirname, 'ignoreNonExistentApplication.js');
        let mtr = new mock_test_1.MockTestRunner(tp);
        mtr.run();
        let errMsg = 'Could not trigger CDDirector for the given application version. Check that the application name and version matches CDDirector.';
        console.log("Task Output: ", mtr.stdout);
        assert.strictEqual(mtr.succeeded, false, 'should have failed');
        assert.strictEqual(mtr.warningIssues.length, 0, "should have no warnings");
        assert.strictEqual(mtr.errorIssues.length, 1, "should have 1 error issue");
        assert.strictEqual(mtr.stdout.indexOf('[INFO] IgnoreNonExistent CDD Application:false') >= 0, true, "Ignore non existent application must be false");
        assert.strictEqual(mtr.stdout.indexOf(STATUS_CODE_404) >= 0, true, "Status code from cdd must be 400");
        assert.strictEqual(mtr.stdout.indexOf(errMsg) >= 0, true, "Task must fail with appropriate error message");
        done();
    });
    it('11- Ignore Non-existent application - checked', function (done) {
        let tp = path.join(__dirname, 'ignoreNonExistentApplication2.js');
        let mtr = new mock_test_1.MockTestRunner(tp);
        mtr.run();
        let errMsg = 'Could not trigger CDDirector for the given application version. Check that the application name and version matches CDDirector.';
        console.log("Task Output: ", mtr.stdout);
        assert.strictEqual(mtr.succeeded, true, 'should have succeeded');
        assert.strictEqual(mtr.warningIssues.length, 0, "should have no warnings");
        assert.strictEqual(mtr.errorIssues.length, 0, "should have no errors");
        assert.strictEqual(mtr.stdout.indexOf('[INFO] IgnoreNonExistent CDD Application:true') >= 0, true, "Ignore non existent application must be false");
        assert.strictEqual(mtr.stdout.indexOf(STATUS_CODE_404) >= 0, true, "Status code from cdd must be 404");
        assert.strictEqual(mtr.stdout.indexOf(TASK_SUCCESS_MSG) >= 0, true, "Task must complete successfully");
        done();
    });
    it('12- Invalid Build Reposiroty URI for application name', function (done) {
        let tp = path.join(__dirname, 'invalidApplicationName.js');
        let mtr = new mock_test_1.MockTestRunner(tp);
        mtr.run();
        let errMsg = 'Cannot extract application name ,reason :invalid repository url samplespringapp';
        console.log("Task Output: ", mtr.stdout);
        assert.strictEqual(mtr.succeeded, false, 'should have failed');
        assert.strictEqual(mtr.warningIssues.length, 0, "should have no warnings");
        assert.strictEqual(mtr.errorIssues.length, 1, "should have 1 error issue");
        assert.strictEqual(mtr.stdout.indexOf(errMsg) >= 0, true, "Task must fail with appropriate error message");
        done();
    });
    it('13- Execute Release maximum inputs', function (done) {
        let tp = path.join(__dirname, 'executeReleaseMaxInputs.js');
        let mtr = new mock_test_1.MockTestRunner(tp);
        mtr.run();
        console.log("Task Output: ", mtr.stdout);
        assert.strictEqual(mtr.succeeded, true, 'should have succeeded');
        assert.strictEqual(mtr.warningIssues.length, 0, "should have no warnings");
        assert.strictEqual(mtr.errorIssues.length, 0, "should have no errors");
        assert.strictEqual(mtr.stdout.indexOf('[INFO] IgnoreNonExistent CDD Application:true') >= 0, true, "Ignore non existent application must be true");
        assert.strictEqual(mtr.stdout.indexOf(STATUS_CODE_200) >= 0, true, "Status code from cdd must be 200");
        assert.strictEqual(mtr.stdout.indexOf(TASK_SUCCESS_MSG) >= 0, true, "Task must complete successfully");
        done();
    });
    it('14- Create Release filesource', function (done) {
        let tp = path.join(__dirname, 'createReleaseFileSource.js');
        let mtr = new mock_test_1.MockTestRunner(tp);
        mtr.run();
        console.log("Task Output: ", mtr.stdout);
        assert.strictEqual(mtr.succeeded, true, 'should have succeeded');
        assert.strictEqual(mtr.warningIssues.length, 0, "should have no warnings");
        assert.strictEqual(mtr.errorIssues.length, 0, "should have no errors");
        assert.strictEqual(mtr.stdout.indexOf('[INFO] IgnoreNonExistent CDD Application:false') >= 0, true, "Ignore non existent application must be false");
        assert.strictEqual(mtr.stdout.indexOf('"releaseDslScope": "APPLICATION"') >= 0, true, "DSL scope must be APPLICATION");
        assert.strictEqual(mtr.stdout.indexOf(STATUS_CODE_200) >= 0, true, "Status code from cdd must be 200");
        assert.strictEqual(mtr.stdout.indexOf(TASK_SUCCESS_MSG) >= 0, true, "Task must complete successfully");
        done();
    });
    it('15- Create Release business application', function (done) {
        let tp = path.join(__dirname, 'createReleaseBusinessApplication.js');
        let mtr = new mock_test_1.MockTestRunner(tp);
        mtr.run();
        console.log("Task Output: ", mtr.stdout);
        assert.strictEqual(mtr.succeeded, true, 'should have succeeded');
        assert.strictEqual(mtr.warningIssues.length, 0, "should have no warnings");
        assert.strictEqual(mtr.errorIssues.length, 0, "should have no errors");
        assert.strictEqual(mtr.stdout.indexOf('[INFO] IgnoreNonExistent CDD Application:false') >= 0, true, "Ignore non existent application must be false");
        assert.strictEqual(mtr.stdout.indexOf('"releaseDslScope": "BUSINESS_APPLICATION"') >= 0, true, "DSL scope must be BUSINESS_APPLICATION");
        assert.strictEqual(mtr.stdout.indexOf(STATUS_CODE_200) >= 0, true, "Status code from cdd must be 200");
        assert.strictEqual(mtr.stdout.indexOf(TASK_SUCCESS_MSG) >= 0, true, "Task must complete successfully");
        done();
    });
    it('16- Run Tests only subset', function (done) {
        let tp = path.join(__dirname, 'runTestsOnlySubset.js');
        let mtr = new mock_test_1.MockTestRunner(tp);
        mtr.run();
        console.log("Task Output: ", mtr.stdout);
        assert.strictEqual(mtr.succeeded, true, 'should have succeeded');
        assert.strictEqual(mtr.warningIssues.length, 0, "should have no warnings");
        assert.strictEqual(mtr.errorIssues.length, 0, "should have no errors");
        assert.strictEqual(mtr.stdout.indexOf('[INFO] IgnoreNonExistent CDD Application:false') >= 0, true, "Ignore non existent application must be false");
        assert.strictEqual(mtr.stdout.indexOf('"releaseDslScope": "ADAPTIVE_TESTING"') >= 0, true, "DSL scope must be Adaptive Testing");
        assert.strictEqual(mtr.stdout.indexOf('"ONLY_INTELLIGENT_TEST_SUITES": true') >= 0, true, "Run subset must be true");
        assert.strictEqual(mtr.stdout.indexOf(STATUS_CODE_200) >= 0, true, "Status code from cdd must be 200");
        assert.strictEqual(mtr.stdout.indexOf(TASK_SUCCESS_MSG) >= 0, true, "Task must complete successfully");
        done();
    });
    it('17- Run Tests All', function (done) {
        let tp = path.join(__dirname, 'runTests.js');
        let mtr = new mock_test_1.MockTestRunner(tp);
        mtr.run();
        console.log("Task Output: ", mtr.stdout);
        assert.strictEqual(mtr.succeeded, true, 'should have succeeded');
        assert.strictEqual(mtr.warningIssues.length, 0, "should have no warnings");
        assert.strictEqual(mtr.errorIssues.length, 0, "should have no errors");
        assert.strictEqual(mtr.stdout.indexOf('[INFO] IgnoreNonExistent CDD Application:false') >= 0, true, "Ignore non existent application must be false");
        assert.strictEqual(mtr.stdout.indexOf('"ONLY_INTELLIGENT_TEST_SUITES": false') >= 0, true, "Run subset must be false");
        assert.strictEqual(mtr.stdout.indexOf('"releaseDslScope": "ADAPTIVE_TESTING"') >= 0, true, "DSL scope must be Adaptive Testing");
        assert.strictEqual(mtr.stdout.indexOf(STATUS_CODE_200) >= 0, true, "Status code from cdd must be 200");
        assert.strictEqual(mtr.stdout.indexOf(TASK_SUCCESS_MSG) >= 0, true, "Task must complete successfully");
        done();
    });
});
